Optimize For GPU
K-Dense-AI/scientific-agent-skills
GPU-accelerates scientific Python on NVIDIA hardware and verifies that the result is correct and faster.
Expert skill for optimized stencil and convolution pattern implementations on GPU.
$ npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install majiayu000/claude-skill-registry stencil-convolution --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/majiayu000/claude-skill-registry.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/ai-ml/stencil-convolution .claude/skills/stencil-convolution && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "stencil-convolution" agent skill from https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolution into .claude/skills/stencil-convolution/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "stencil-convolution", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolutionType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install majiayu000/claude-skill-registry stencil-convolution --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/majiayu000/claude-skill-registry.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/ai-ml/stencil-convolution .agents/skills/stencil-convolution && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "stencil-convolution" agent skill from https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolution into .agents/skills/stencil-convolution/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "stencil-convolution", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install majiayu000/claude-skill-registry stencil-convolution --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/majiayu000/claude-skill-registry.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/ai-ml/stencil-convolution .cursor/skills/stencil-convolution && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "stencil-convolution" agent skill from https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolution into .cursor/skills/stencil-convolution/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "stencil-convolution", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/majiayu000/claude-skill-registry.git --path skills/ai-ml/stencil-convolution--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install majiayu000/claude-skill-registry stencil-convolution --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/majiayu000/claude-skill-registry.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/ai-ml/stencil-convolution .gemini/skills/stencil-convolution && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "stencil-convolution" agent skill from https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolution into .gemini/skills/stencil-convolution/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "stencil-convolution", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install majiayu000/claude-skill-registry stencil-convolutionInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/majiayu000/claude-skill-registry.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/ai-ml/stencil-convolution .github/skills/stencil-convolution && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "stencil-convolution" agent skill from https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolution into .github/skills/stencil-convolution/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "stencil-convolution", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install majiayu000/claude-skill-registry stencil-convolution --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/majiayu000/claude-skill-registry.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/ai-ml/stencil-convolution .opencode/skills/stencil-convolution && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "stencil-convolution" agent skill from https://github.com/majiayu000/claude-skill-registry/tree/main/skills/ai-ml/stencil-convolution into .opencode/skills/stencil-convolution/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "stencil-convolution", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
stencil-convolutionExpert skill for optimized stencil and convolution pattern implementations on GPU.
Stencil Convolution is an agent skill from majiayu000/claude-skill-registry. Expert skill for optimized stencil and convolution pattern implementations on GPU. Design tiled stencil algorithms with halos, implement 2D/3D convolution kernels, optimize boundary condition handling, apply temporal blocking techniques, generate separable filter implementations, and profile stencil memory bandwidth.
Its SKILL.md is about 4k tokens, which your agent loads only when the skill is triggered. The skill folder holds 1 other file (for example `metadata.json`).
The repository describes itself as: Searchable Claude Code skills catalog with source-linked guides and generated registry artifacts. The licence is MIT.
8 steps, taken from the step headings in SKILL.md.
Read from SKILL.md and the folder at commit 2d14a69. It shows what the files ask for, not the result of running them.
Pre-approves these tools, so the agent can use them without asking each time:
Bash(*)ReadWriteEditGlobGrepWebFetchFrom allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are cuda and json).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Stencil Convolution loads about 4k tokens when it runs. Until then it costs about 85 tokens; SKILL.md has 289 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check noted patterns worth knowing about, such as sudo or a known installer.
allowed-tools: Bash(*), Read, Write, Edit, Glob, Grep, WebFetchAutomated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from majiayu000/claude-skill-registry at commit 2d14a69, republished under its MIT licence (© majiayu000). 289 words, ~4,005 tokens.
.claude/skills/stencil-convolution/SKILL.md (or your agent's skills folder). This skill also uses 1 other file; get the full folder from GitHub.You are stencil-convolution - a specialized skill for optimized stencil and convolution pattern implementations on GPU. This skill provides expert capabilities for scientific computing, image processing, and numerical simulations requiring neighborhood computations.
This skill enables AI-powered stencil and convolution operations including:
// Naive 5-point stencil (for comparison)
__global__ void laplacian2D_naive(
float* out, const float* in,
int width, int height
) {
int x = blockIdx.x * blockDim.x + threadIdx.x;
int y = blockIdx.y * blockDim.y + threadIdx.y;
if (x >= 1 && x < width - 1 && y >= 1 && y < height - 1) {
int idx = y * width + x;
out[idx] = -4.0f * in[idx]
+ in[idx - 1] // left
+ in[idx + 1] // right
+ in[idx - width] // up
+ in[idx + width]; // down
}
}#define TILE_X 32
#define TILE_Y 32
#define HALO 1
__global__ void laplacian2D_tiled(
float* out, const float* in,
int width, int height
) {
// Shared memory with halo
__shared__ float tile[TILE_Y + 2 * HALO][TILE_X + 2 * HALO];
// Global coordinates
int gx = blockIdx.x * TILE_X + threadIdx.x;
int gy = blockIdx.y * TILE_Y + threadIdx.y;
// Local coordinates in shared memory (offset by halo)
int lx = threadIdx.x + HALO;
int ly = threadIdx.y + HALO;
// Load center tile
if (gx < width && gy < height) {
tile[ly][lx] = in[gy * width + gx];
}
// Load halo regions
// Left halo
if (threadIdx.x < HALO && gx >= HALO) {
tile[ly][lx - HALO] = in[gy * width + (gx - HALO)];
}
// Right halo
if (threadIdx.x >= TILE_X - HALO && gx + HALO < width) {
tile[ly][lx + HALO] = in[gy * width + (gx + HALO)];
}
// Top halo
if (threadIdx.y < HALO && gy >= HALO) {
tile[ly - HALO][lx] = in[(gy - HALO) * width + gx];
}
// Bottom halo
if (threadIdx.y >= TILE_Y - HALO && gy + HALO < height) {
tile[ly + HALO][lx] = in[(gy + HALO) * width + gx];
}
// Corner halos (if needed for larger stencils)
// ...
__syncthreads();
// Compute stencil using shared memory
if (gx >= 1 && gx < width - 1 && gy >= 1 && gy < height - 1) {
out[gy * width + gx] = -4.0f * tile[ly][lx]
+ tile[ly][lx - 1]
+ tile[ly][lx + 1]
+ tile[ly - 1][lx]
+ tile[ly + 1][lx];
}
}template <int RADIUS>
__global__ void stencil2D_generic(
float* out, const float* in,
const float* weights, // Stencil weights
int width, int height
) {
extern __shared__ float tile[];
const int TILE_X = blockDim.x;
const int TILE_Y = blockDim.y;
const int TILE_PITCH = TILE_X + 2 * RADIUS;
int gx = blockIdx.x * TILE_X + threadIdx.x;
int gy = blockIdx.y * TILE_Y + threadIdx.y;
int lx = threadIdx.x + RADIUS;
int ly = threadIdx.y + RADIUS;
// Load tile with halos
// ... (similar to above but generic)
__syncthreads();
if (gx >= RADIUS && gx < width - RADIUS &&
gy >= RADIUS && gy < height - RADIUS) {
float result = 0.0f;
int wIdx = 0;
// Apply stencil weights
for (int dy = -RADIUS; dy <= RADIUS; dy++) {
for (int dx = -RADIUS; dx <= RADIUS; dx++) {
result += weights[wIdx++] * tile[(ly + dy) * TILE_PITCH + (lx + dx)];
}
}
out[gy * width + gx] = result;
}
}#define CONV_TILE_X 32
#define CONV_TILE_Y 32
#define MAX_KERNEL_RADIUS 8
// Kernel weights in constant memory for fast access
__constant__ float c_kernel[(2 * MAX_KERNEL_RADIUS + 1) * (2 * MAX_KERNEL_RADIUS + 1)];
__global__ void convolution2D(
float* out, const float* in,
int width, int height,
int kernelRadius
) {
extern __shared__ float tile[];
int TILE_PITCH = CONV_TILE_X + 2 * kernelRadius;
int gx = blockIdx.x * CONV_TILE_X + threadIdx.x;
int gy = blockIdx.y * CONV_TILE_Y + threadIdx.y;
int lx = threadIdx.x + kernelRadius;
int ly = threadIdx.y + kernelRadius;
// Load center
if (gx < width && gy < height) {
tile[ly * TILE_PITCH + lx] = in[gy * width + gx];
} else {
tile[ly * TILE_PITCH + lx] = 0.0f; // Zero padding
}
// Load halos with boundary handling
// Left
if (threadIdx.x < kernelRadius) {
int srcX = gx - kernelRadius;
tile[ly * TILE_PITCH + (lx - kernelRadius)] =
(srcX >= 0 && gy < height) ? in[gy * width + srcX] : 0.0f;
}
// Right
if (threadIdx.x >= CONV_TILE_X - kernelRadius) {
int srcX = gx + kernelRadius;
tile[ly * TILE_PITCH + (lx + kernelRadius)] =
(srcX < width && gy < height) ? in[gy * width + srcX] : 0.0f;
}
// Top and bottom (similar pattern)
// ...
__syncthreads();
if (gx < width && gy < height) {
float sum = 0.0f;
int kernelSize = 2 * kernelRadius + 1;
for (int ky = -kernelRadius; ky <= kernelRadius; ky++) {
for (int kx = -kernelRadius; kx <= kernelRadius; kx++) {
int kidx = (ky + kernelRadius) * kernelSize + (kx + kernelRadius);
sum += c_kernel[kidx] * tile[(ly + ky) * TILE_PITCH + (lx + kx)];
}
}
out[gy * width + gx] = sum;
}
}// Separable convolution is faster: O(2*r) vs O(r^2)
// First pass: horizontal convolution
__global__ void convolutionRow(
float* out, const float* in,
int width, int height, int radius
) {
extern __shared__ float tile[];
int gx = blockIdx.x * blockDim.x + threadIdx.x;
int gy = blockIdx.y;
int TILE_WIDTH = blockDim.x + 2 * radius;
int lx = threadIdx.x + radius;
// Load with halos
if (gx < width) {
tile[lx] = in[gy * width + gx];
}
if (threadIdx.x < radius) {
tile[threadIdx.x] = (gx >= radius) ? in[gy * width + gx - radius] : 0.0f;
tile[lx + blockDim.x] = (gx + blockDim.x < width) ?
in[gy * width + gx + blockDim.x] : 0.0f;
}
__syncthreads();
if (gx < width) {
float sum = 0.0f;
for (int k = -radius; k <= radius; k++) {
sum += c_kernelRow[k + radius] * tile[lx + k];
}
out[gy * width + gx] = sum;
}
}
// Second pass: vertical convolution
__global__ void convolutionColumn(
float* out, const float* in,
int width, int height, int radius
) {
extern __shared__ float tile[];
int gx = blockIdx.x;
int gy = blockIdx.y * blockDim.y + threadIdx.y;
int TILE_HEIGHT = blockDim.y + 2 * radius;
int ly = threadIdx.y + radius;
// Load with halos
if (gy < height) {
tile[ly] = in[gy * width + gx];
}
if (threadIdx.y < radius) {
tile[threadIdx.y] = (gy >= radius) ? in[(gy - radius) * width + gx] : 0.0f;
tile[ly + blockDim.y] = (gy + blockDim.y < height) ?
in[(gy + blockDim.y) * width + gx] : 0.0f;
}
__syncthreads();
if (gy < height) {
float sum = 0.0f;
for (int k = -radius; k <= radius; k++) {
sum += c_kernelCol[k + radius] * tile[ly + k];
}
out[gy * width + gx] = sum;
}
}#define TILE_X 16
#define TILE_Y 16
#define TILE_Z 4
__global__ void laplacian3D(
float* out, const float* in,
int nx, int ny, int nz
) {
__shared__ float current[TILE_Y + 2][TILE_X + 2];
__shared__ float above[TILE_Y][TILE_X];
__shared__ float below[TILE_Y][TILE_X];
int gx = blockIdx.x * TILE_X + threadIdx.x;
int gy = blockIdx.y * TILE_Y + threadIdx.y;
int gz = blockIdx.z * TILE_Z;
int lx = threadIdx.x + 1;
int ly = threadIdx.y + 1;
// Process TILE_Z planes
for (int z = gz; z < min(gz + TILE_Z, nz - 1); z++) {
if (z == 0) continue;
// Load current plane with halos
if (gx < nx && gy < ny) {
current[ly][lx] = in[z * ny * nx + gy * nx + gx];
}
// Load halos
if (threadIdx.x == 0 && gx > 0) {
current[ly][0] = in[z * ny * nx + gy * nx + (gx - 1)];
}
if (threadIdx.x == TILE_X - 1 && gx < nx - 1) {
current[ly][TILE_X + 1] = in[z * ny * nx + gy * nx + (gx + 1)];
}
if (threadIdx.y == 0 && gy > 0) {
current[0][lx] = in[z * ny * nx + (gy - 1) * nx + gx];
}
if (threadIdx.y == TILE_Y - 1 && gy < ny - 1) {
current[TILE_Y + 1][lx] = in[z * ny * nx + (gy + 1) * nx + gx];
}
// Load above and below planes
if (gx < nx && gy < ny) {
above[threadIdx.y][threadIdx.x] = in[(z + 1) * ny * nx + gy * nx + gx];
below[threadIdx.y][threadIdx.x] = in[(z - 1) * ny * nx + gy * nx + gx];
}
__syncthreads();
// Compute 7-point stencil
if (gx >= 1 && gx < nx - 1 && gy >= 1 && gy < ny - 1) {
out[z * ny * nx + gy * nx + gx] =
-6.0f * current[ly][lx]
+ current[ly][lx - 1] // x-1
+ current[ly][lx + 1] // x+1
+ current[ly - 1][lx] // y-1
+ current[ly + 1][lx] // y+1
+ above[threadIdx.y][threadIdx.x] // z+1
+ below[threadIdx.y][threadIdx.x]; // z-1
}
__syncthreads();
}
}// Process multiple timesteps before writing back to global memory
template <int TIMESTEPS>
__global__ void stencil_temporal_blocking(
float* out, const float* in,
int width, int height
) {
// Larger shared memory to accommodate temporal expansion
// Each timestep expands the halo by 1
const int HALO = TIMESTEPS;
extern __shared__ float smem[];
float* current = smem;
float* next = smem + (blockDim.y + 2 * HALO) * (blockDim.x + 2 * HALO);
// Load initial data with expanded halo
// ...
__syncthreads();
// Multiple timesteps in shared memory
for (int t = 0; t < TIMESTEPS; t++) {
int shrinkHalo = TIMESTEPS - t - 1;
int validXStart = shrinkHalo;
int validXEnd = blockDim.x + 2 * HALO - shrinkHalo;
int validYStart = shrinkHalo;
int validYEnd = blockDim.y + 2 * HALO - shrinkHalo;
int lx = threadIdx.x + HALO;
int ly = threadIdx.y + HALO;
// Only threads in valid region compute
if (lx >= validXStart + 1 && lx < validXEnd - 1 &&
ly >= validYStart + 1 && ly < validYEnd - 1) {
int PITCH = blockDim.x + 2 * HALO;
next[ly * PITCH + lx] = -4.0f * current[ly * PITCH + lx]
+ current[ly * PITCH + lx - 1]
+ current[ly * PITCH + lx + 1]
+ current[(ly - 1) * PITCH + lx]
+ current[(ly + 1) * PITCH + lx];
}
__syncthreads();
// Swap buffers
float* temp = current;
current = next;
next = temp;
__syncthreads();
}
// Write final result to global memory
// ...
}// Different boundary condition strategies
enum BoundaryCondition {
BC_ZERO, // Zero padding
BC_REPLICATE, // Replicate edge values
BC_REFLECT, // Mirror reflection
BC_PERIODIC // Wrap around
};
__device__ inline int applyBoundary(int idx, int size, BoundaryCondition bc) {
if (idx >= 0 && idx < size) return idx;
switch (bc) {
case BC_ZERO:
return -1; // Signal to use zero
case BC_REPLICATE:
return (idx < 0) ? 0 : size - 1;
case BC_REFLECT:
if (idx < 0) return -idx - 1;
if (idx >= size) return 2 * size - idx - 1;
return idx;
case BC_PERIODIC:
return ((idx % size) + size) % size;
default:
return idx;
}
}
__device__ inline float loadWithBoundary(
const float* data, int x, int y,
int width, int height, BoundaryCondition bc
) {
int bx = applyBoundary(x, width, bc);
int by = applyBoundary(y, height, bc);
if (bx < 0 || by < 0) return 0.0f;
return data[by * width + bx];
}| Pattern | Impact | Recommendation |
|---|---|---|
| Coalesced global reads | High | Align thread access to memory layout |
| Shared memory bank conflicts | Medium | Pad shared memory arrays |
| Halo loading efficiency | Medium | Use cooperative loading |
| GPU Architecture | Recommended Tile Size |
|---|---|
| Volta/Turing | 32x32 or 16x16 |
| Ampere | 32x32 |
| Hopper | 32x32 or 64x32 |
This skill integrates with the following processes:
stencil-computation-optimization.js - Stencil optimization workflowsgpu-image-video-processing.js - Image filteringparallel-algorithm-design.js - Algorithm patternsWhen executing operations, provide structured output:
{
"operation": "generate-stencil",
"status": "success",
"stencil": {
"type": "2D",
"points": 5,
"radius": 1,
"boundary": "replicate"
},
"optimization": {
"tile_size": [32, 32],
"shared_memory_bytes": 4624,
"halo_size": 1,
"temporal_blocking": false
},
"performance": {
"achieved_bandwidth_gbps": 850,
"peak_bandwidth_gbps": 1555,
"efficiency_percent": 54.7
},
"recommendations": [
"Consider separable implementation for Gaussian filter",
"Temporal blocking could reduce memory traffic by 2x"
],
"artifacts": ["stencil_kernel.cu", "benchmark_results.json"]
}© majiayu000, MIT. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
SKILL.md and 1 other file in skills/ai-ml/stencil-convolution of majiayu000/claude-skill-registry.
Open the folder on GitHubat commit 2d14a69
We found 1 copy of this SKILL.md (exact, near-identical or edited) in other folders, from 1 other GitHub owner. This page covers the copy in majiayu000/claude-skill-registry, which our catalogue first saw on October 7, 2026.
Stencil Convolution next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Stencil Convolution this skillmajiayu000/claude-skill-registry | 666 | 1 repos | ~4k | Automated safety check: Notes | MIT | |
| Optimize For GPUK-Dense-AI/scientific-agent-skills | 48k | 1 repos | ~3.4k | Automated safety check: Pass | MIT | |
| SQL Optimization Patternssickn33/agentic-awesome-skills | 47k | 1 repos | ~566 | Automated safety check: Pass | MIT | |
| Auth Implementation Patternssickn33/agentic-awesome-skills | 47k | 1 repos | ~649 | Automated safety check: Pass | MIT | |
| Postgres Patternsaffaan-m/ECC | 275k | — | ~1k | Automated safety check: Pass | MIT | |
| Jpa Patternsaffaan-m/ECC | 275k | 5 repos | ~1.2k | Automated safety check: Pass | MIT |
K-Dense-AI/scientific-agent-skills
GPU-accelerates scientific Python on NVIDIA hardware and verifies that the result is correct and faster.
sickn33/agentic-awesome-skills
Diagnose slow SQL with query plans, preserve query results, and verify indexing or query changes against representative data.
sickn33/agentic-awesome-skills
Implement or review authentication and authorization with explicit token, session and resource-access boundaries.
affaan-m/ECC
PostgreSQL database patterns for query optimization, schema design, indexing, and security.
affaan-m/ECC
JPA/Hibernate patterns for entity design, relationships, query optimization, transactions, auditing, indexing, pagination, and pooling in Spring Boot.
affaan-m/ECC
Prisma ORM patterns for TypeScript backends — schema design, query optimization, transactions, pagination, and critical traps like updateMany returning count not records, $transaction timeouts…
majiayu000/claude-skill-registry
Multi-source deep research using firecrawl and exa MCPs. An agent skill from majiayu000/claude-skill-registry.
majiayu000/claude-skill-registry
Neural search via Exa MCP for web, code, and company research.
majiayu000/claude-skill-registry
Unified media generation via fal.ai MCP — image, video, and audio.
majiayu000/claude-skill-registry
Interact with Zotero reference management libraries using the pyzotero Python client.
majiayu000/claude-skill-registry
Search scientific papers and retrieve structured experimental data extracted from full-text studies via the BGPT MCP server.
majiayu000/claude-skill-registry
Perform pairwise sequence alignment using Biopython Bio.Align.PairwiseAligner.
Expert skill for optimized stencil and convolution pattern implementations on GPU. Stencil Convolution is an agent skill from majiayu000/claude-skill-registry. Expert skill for optimized stencil and convolution pattern implementations on GPU.
Run `npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a claude-code`. Or copy the skill folder (skills/ai-ml/stencil-convolution in majiayu000/claude-skill-registry) into .claude/skills/stencil-convolution in your project. Claude Code loads it when a task matches its description.
Run `npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a codex`. Or copy the skill folder (skills/ai-ml/stencil-convolution in majiayu000/claude-skill-registry) into .agents/skills/stencil-convolution in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add majiayu000/claude-skill-registry --skill stencil-convolution -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/stencil-convolution, .gemini/skills/stencil-convolution, .github/skills/stencil-convolution and .opencode/skills/stencil-convolution in your project.
SKILL.md names no scripts, command-line tools or credentials: Stencil Convolution is instructions for the agent only. Its frontmatter pre-approves these tools: Bash(*), Read, Write, Edit, Glob, Grep, WebFetch.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found notes only (pre-approves every shell command (allowed-tools: bash)), nothing it rates as a warning. It is not a guarantee. Review the folder before installing.
Stencil Convolution is published under the MIT licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 4k tokens (SKILL.md is roughly 16k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Stencil Convolution: Optimize For GPU (K-Dense-AI/scientific-agent-skills, 48k stars), SQL Optimization Patterns (sickn33/agentic-awesome-skills, 47k stars), Auth Implementation Patterns (sickn33/agentic-awesome-skills, 47k stars) and Postgres Patterns (affaan-m/ECC, 275k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
majiayu000 (a GitHub user) maintains it in majiayu000/claude-skill-registry, which has 666 GitHub stars. The repository holds 1,273 skills in this directory. The repository was last updated on October 7, 2026.
Source: majiayu000/claude-skill-registry on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.